==> 0.1.4.tar.gz: lib/src/cards/card_item.dart <==
import 'package:flutter/material.dart';

/// Displays its integer item as 'item N' on a Card whose color is based on
/// the item's value. The text is displayed in bright green if selected is true.
/// This widget's height is based on the animation parameter, it varies
/// from 0 to 128 as the animation varies from 0.0 to 1.0.
class CardItem extends StatefulWidget  {
  final Animation<double> animation;
  final VoidCallback onTap;
  final int item;
  final bool selected;
  const CardItem({Key key, this.animation, this.onTap, this.item, this.selected}) : super(key: key);

  @override
  _CardItemState createState() => _CardItemState(animation: this.animation, item: this.item, onTap: this.onTap);
  
}

class _CardItemState extends State<CardItem> with SingleTickerProviderStateMixin {

  _CardItemState({
    @required this.animation,
    this.onTap,
    @required this.item,
    this.selected: false}
  )
  : assert(animation != null),
    assert(item != null && item >= 0),
    assert(selected != null);
    //super(key: key);

  final Animation<double> animation;
  final VoidCallback onTap;
  final int item;
  final bool selected;

  AnimationController _controller;
  Animation<Offset> _offsetAnimation;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      duration: const Duration(seconds: 2),
      vsync: this,
    ); //..repeat(reverse: false);
    _offsetAnimation = 
    
    Tween<Offset>(
      begin: const Offset(1.5, 0.0),
      end: Offset.zero,
    ).animate( CurvedAnimation(
      parent: _controller,
      curve: Curves.easeInOutExpo,
    ));
    _controller.forward();
  }

  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    TextStyle textStyle = Theme.of(context).textTheme.headline4;
    if (selected)
      textStyle = textStyle.copyWith(color: Colors.lightGreenAccent[400]);
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: SlideTransition(
        position: _offsetAnimation,
        child: GestureDetector(
          behavior: HitTestBehavior.opaque,
          onTap: onTap,
          child: SizedBox(
            height: 128.0,
            child: Card(
              color: Colors.primaries[item % Colors.primaries.length],
              child: Center(
                child: Text('Item $item', style: textStyle),
              ),
            ),
          ),
        ),
      ),
    );
  }
}


/* Backup

 Widget build(BuildContext context) {
    TextStyle textStyle = Theme.of(context).textTheme.headline4;
    if (selected)
      textStyle = textStyle.copyWith(color: Colors.lightGreenAccent[400]);
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: SizeTransition(
        axis: Axis.vertical,
        sizeFactor: animation,
        child: GestureDetector(
          behavior: HitTestBehavior.opaque,
          onTap: onTap,
          child: SizedBox(
            height: 128.0,
            child: Card(
              color: Colors.primaries[item % Colors.primaries.length],
              child: Center(
                child: Text('Item $item', style: textStyle),
              ),
            ),
          ),
        ),
      ),
    ); */

==> 0.1.6.tar.gz: lib/src/cards/card_item.dart <==
import 'package:flutter/material.dart';

/// Displays its integer item as 'item N' on a Card whose color is based on
/// the item's value. The text is displayed in bright green if selected is true.
/// This widget's height is based on the animation parameter, it varies
/// from 0 to 128 as the animation varies from 0.0 to 1.0.
class CardItem extends StatefulWidget  {
  final Animation<double>? animation;
  final VoidCallback? onTap;
  final int? item;
  final bool? selected;
  const CardItem({Key? key, this.animation, this.onTap, this.item, this.selected}) : super(key: key);

  @override
  _CardItemState createState() => _CardItemState(animation: this.animation!, item: this.item, onTap: this.onTap);
  
}

class _CardItemState extends State<CardItem> with SingleTickerProviderStateMixin {

  _CardItemState({
    required this.animation,
    this.onTap,
    this.item,
    this.selected: false}
  )
  : assert(item != null && item >= 0);
    //super(key: key);

  final Animation<double> animation;
  final VoidCallback? onTap;
  final int? item;
  final bool selected;

  late AnimationController _controller;
  late Animation<Offset> _offsetAnimation;

  @override
  void initState() {
    super.initState();
    _controller = AnimationController(
      duration: const Duration(seconds: 2),
      vsync: this,
    ); //..repeat(reverse: false);
    _offsetAnimation = 
    
    Tween<Offset>(
      begin: const Offset(1.5, 0.0),
      end: Offset.zero,
    ).animate( CurvedAnimation(
      parent: _controller,
      curve: Curves.easeInOutExpo,
    ));
    _controller.forward();
  }

  @override
  void dispose() {
    super.dispose();
    _controller.dispose();
  }

  @override
  Widget build(BuildContext context) {
    TextStyle? textStyle = Theme.of(context).textTheme.headline4;
    if (selected)
      textStyle = textStyle!.copyWith(color: Colors.lightGreenAccent[400]);
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: SlideTransition(
        position: _offsetAnimation,
        child: GestureDetector(
          behavior: HitTestBehavior.opaque,
          onTap: onTap,
          child: SizedBox(
            height: 128.0,
            child: Card(
              color: Colors.primaries[item! % Colors.primaries.length],
              child: Center(
                child: Text('Item $item', style: textStyle),
              ),
            ),
          ),
        ),
      ),
    );
  }
}


/* Backup

 Widget build(BuildContext context) {
    TextStyle textStyle = Theme.of(context).textTheme.headline4;
    if (selected)
      textStyle = textStyle.copyWith(color: Colors.lightGreenAccent[400]);
    return Padding(
      padding: const EdgeInsets.all(2.0),
      child: SizeTransition(
        axis: Axis.vertical,
        sizeFactor: animation,
        child: GestureDetector(
          behavior: HitTestBehavior.opaque,
          onTap: onTap,
          child: SizedBox(
            height: 128.0,
            child: Card(
              color: Colors.primaries[item % Colors.primaries.length],
              child: Center(
                child: Text('Item $item', style: textStyle),
              ),
            ),
          ),
        ),
      ),
    ); */
